
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
url
distfile
savefile
fakeroot
SHA
ospkg
os
workdir
init
James
Wilkus
jfwilkus
lib
OS
Package
System
Artifact
Factory
Config
Plugin
Solaris
IPS
Role
Validate
Clean
CLI
Prune
Build
Download
Linux
RPM
Maintainer
Application
SVR4
Extract
deb
Log
Init
